@@ -12,7 +12,7 @@
 #' barplot(t(as.matrix(gl.alf(possums.gl[,1:10]))))
 
 gl.alf <- function(x) {
-  alf <- colMeans(as.matrix(x), na.rm = T) / 2
+  alf <- colMeans(as.matrix(x), na.rm = TRUE) / 2
   out <- data.frame(alf1 = 1 - alf, alf2 = alf)
   return(out)
 }
