@@ -41,7 +41,7 @@ gl.costdistances <- function(landscape,
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
                      build = "Jody",
-                     verbosity = verbose)
+                     verbose = verbose)
     
     # CHECK IF PACKAGES ARE INSTALLED
     pkg <- "gdistance"
