@@ -1,70 +1,67 @@
 #' @name gl.drop.ind
-#' @title Removes specified individuals from a genlight object
+# Preliminaries -- Parameter specifications -------------- 
+#' @title Removes specified individuals from a dartR genlight object
 #' @description
-#' The script, having deleted individuals, optionally identifies resultant
-#' monomorphic loci or loci with all values missing and deletes them
-#' (using gl.filter.monomorphs.r). The script also optionally recalculates
-#' statistics made redundant by the deletion of individuals from the dataset.
+#' This function deletes individuals and their associated metadata.
+#' Monomorphic loci and loci that are scored all NA are optionally deleted (mono.rm=TRUE). 
+#' The script also optionally recalculates locus metatdata statistics to accommodate
+#' the deletion of individuals from the dataset (recalc=TRUE).
 #'
-#' The script returns a genlight object with the individuals deleted and,
-#' optionally, the recalculated locus metadata.
+#' The script returns a dartR genlight object with the retained individuals 
+#' and the recalculated locus metadata. The script works with both genlight objects
+#' containing SNP genotypes and Tag P/A data (SilicoDArT).
 #' 
-#' #' See more about data manipulation in the [tutorial](http://georges.biomatix.org/storage/app/media/uploaded-files/tutorial4dartrdatamanipulation22-dec-21-3.pdf).
-#'
-#' @param x Name of the genlight object containing SNP genotypes [required].
-#' @param ind.list A list of individuals to be removed [required].
-#' @param recalc Recalculate the locus metadata statistics [default FALSE].
-#' @param mono.rm Remove monomorphic loci [default FALSE].
+#' @param x Name of the genlight object [required].
+#' @param ind.list List of individuals to be removed [required].
+#' @param recalc If TRUE, recalculate the locus metadata statistics [default FALSE].
+#' @param mono.rm If TRUE, remove monomorphic and all NA loci [default FALSE].
 #' @param verbose Verbosity: 0, silent or fatal errors; 1, begin and end; 2,
-#' progress log; 3, progress and results summary; 5, full report
-#' [default 2 or as specified using gl.set.verbosity].
-#' @return A genlight object with the reduced data
+#' progress but not results; 3, progress and results summary; 5, full report
+#'  [default 2 or as specified using gl.set.verbosity].
+
+#' @export
+#' @return A reduced dartR genlight object
+#'
+#' @family dartR-base
 #' @author Custodian: Arthur Georges -- Post to
 #' \url{https://groups.google.com/d/forum/dartr}
+# Examples -------------
 #' @examples
 #'  # SNP data
 #'    gl2 <- gl.drop.ind(testset.gl,
 #'    ind.list=c('AA019073','AA004859'))
-#'    gl2 <- gl.drop.ind(testset.gl,
-#'    ind.list=c('AA019073','AA004859'))
 #'  # Tag P/A data
 #'    gs2 <- gl.drop.ind(testset.gs,
 #'    ind.list=c('AA020656','AA19077','AA004859'))
 #'    gs2 <- gl.drop.ind(testset.gs, ind.list=c('AA020656'
 #'    ,'AA19077','AA004859'),mono.rm=TRUE, recalc=TRUE)
-#'
+# See also ------------
 #' @seealso \code{\link{gl.keep.ind}} to keep rather than drop specified
 #' individuals
-#' @export
-
+# --------------
+# Function 
 gl.drop.ind <- function(x,
                         ind.list,
                         recalc = FALSE,
                         mono.rm = FALSE,
                         verbose = NULL) {
-    # SET VERBOSITY
+   # Preliminaries -------------
+   # SET VERBOSITY
     verbose <- gl.check.verbosity(verbose)
     
     # FLAG SCRIPT START
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
-                     build = "v.2023.1",
-                     verbosity = verbose)
+                     build = "v.2023.2",
+                     verbose = verbose)
     
     # CHECK DATATYPE
     datatype <- utils.check.datatype(x, verbose = verbose)
     
-    # FUNCTION SPECIFIC ERROR CHECKING
-    
+   # Function-specific error checking -----------    
     for (case in ind.list) {
         if (!(case %in% indNames(x))) {
-            cat(
-                warn(
-                    "  Warning: Listed individual",
-                    case,
-                    "not present in the dataset -- ignored\n"
-                )
-            )
+            cat(warn("  Warning: Listed individual",case,"not present in the dataset -- ignored\n"))
             ind.list <- ind.list[!(ind.list == case)]
         }
     }
@@ -72,11 +69,10 @@ gl.drop.ind <- function(x,
         stop(error("Fatal Error: no individuals to drop!\n"))
     }
     
-    # DO THE JOB
-    
     hold <- x
     
-    # Remove individuals
+	# DO THE JOB --------------
+    # Remove individuals ------
     
     if (verbose >= 2) {
         cat(report("  Deleting specified individuals\n"))
@@ -88,13 +84,13 @@ gl.drop.ind <- function(x,
     # Delete listed individuals, recalculate relevant locus metadata and remove monomorphic loci
     
     # Remove rows flagged for deletion
-    inds_to_drop <- which(!x$ind.names %in% ind.list)
-    x <- x[inds_to_drop,]
+    ind.to.keep <- which(!x$ind.names %in% ind.list)
+    x <- x[ind.to.keep,]
 
     # Monomorphic loci may have been created
     x@other$loc.metrics.flags$monomorphs <- FALSE
     
-    # Remove monomorphic loci
+   # Monomorphic loci may have been created ------
     if (mono.rm) {
         if (verbose >= 2) {
             cat(report("  Deleting monomorphic loc\n"))
@@ -110,7 +106,7 @@ gl.drop.ind <- function(x,
         }
     }
     
-    # Recalculate statistics
+   # Recalculate statistics ----------
     if (recalc) {
         x <- gl.recalc.metrics(x, verbose = 0)
         if (verbose >= 2) {
@@ -122,9 +118,10 @@ gl.drop.ind <- function(x,
             x <- utils.reset.flags(x, verbose = 0)
         }
     }
-    
-    # REPORT A SUMMARY
-    
+    # End block -----------
+	
+# REPORT A SUMMARY -------------
+    # Summary of outcomes --------------
     if (verbose >= 3) {
         cat("Summary of recoded dataset\n")
         cat(paste("  No. of loci:", nLoc(x), "\n"))
@@ -134,15 +131,15 @@ gl.drop.ind <- function(x,
         cat(paste("  No. of populations: ", nPop(x), "\n"))
     }
     
-    # ADD TO HISTORY
+# ADD TO HISTORY ------
     nh <- length(x@other$history)
     x@other$history[[nh + 1]] <- match.call()
     
-    # FLAG SCRIPT END
+# FLAG SCRIPT END ------
     
     if (verbose > 0) {
         cat(report("Completed:", funname, "\n"))
     }
-    
+ # End block -----  
     return(x)
 }
