@@ -1,55 +1,61 @@
 #' @name gl.drop.loc
-#' @title Removes specified loci from a genlight object
+# Preliminaries -- Parameter specifications -------------- 
+#' @title Removes specified loci from a dartR genlight object
 #' @description
-#' The script returns a genlight object with specified loci deleted.
-#' 
-#' #' See more about data manipulation in the [tutorial](http://georges.biomatix.org/storage/app/media/uploaded-files/tutorial4dartrdatamanipulation22-dec-21-3.pdf).
+#' This function deletes individuals and their associated metadata. 
 #'
-#' @param x Name of the genlight object containing SNP genotypes or
-#' presence/absence data [required].
+#' The script returns a dartR genlight object with the retained loci. 
+#' The script works with both genlight objects
+#' containing SNP genotypes and Tag P/A data (SilicoDArT).
+#'
+#' @param x Name of the genlight object [required].
 #' @param loc.list A list of loci to be deleted
 #' [required, if loc.range not specified].
-#' @param first First of a range of loci to be deleted
+#' @param first_tmp First of a range of loci to be deleted
 #' [required, if loc.list not specified].
-#' @param last Last of a range of loci to be deleted
-#' [if not specified, last locus in the dataset].
+#' @param last_tmp Last of a range of loci to be deleted
+#' [if not specified, last_tmp locus in the dataset].
 #' @param verbose Verbosity: 0, silent or fatal errors; 1, begin and end; 2,
-#' progress log; 3, progress and results summary; 5, full report
-#' [default 2 or as specified using gl.set.verbosity].
-#' @return A genlight object with the reduced data.
+#' progress but not results; 3, progress and results summary; 5, full report
+#'  [default 2 or as specified using gl.set.verbosity].
 #'
+#' @export
+#' @return A reduced dartR genlight object
+#'
+#' @family dartR-base
 #' @author Custodian: Arthur Georges -- Post to
 #' \url{https://groups.google.com/d/forum/dartr}
-#'
+# Examples -------------
 #' @examples
 #' # SNP data
 #'   gl2 <- gl.drop.loc(testset.gl, loc.list=c('100051468|42-A/T', '100049816-51-A/G'),verbose=3)
 #' # Tag P/A data
 #'   gs2 <- gl.drop.loc(testset.gs, loc.list=c('20134188','19249144'),verbose=3)
-#'
+# See also ------------
 #' @seealso \code{\link{gl.keep.loc}} to keep rather than drop specified loci
-#' @export
 #'
+# End Block --------------
+# Function 
 gl.drop.loc <- function(x,
                         loc.list = NULL,
-                        first = NULL,
-                        last = NULL,
+                        first_tmp = NULL,
+                        last_tmp = NULL,
                         verbose = NULL) {
+  # Preliminaries -------------
     # SET VERBOSITY
     verbose <- gl.check.verbosity(verbose)
     
     # FLAG SCRIPT START
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
-                     build = "v.2023.1",
-                     verbosity = verbose)
+                     build = "v.2023.2",
+                     verbose = verbose)
     
     # CHECK DATATYPE
     datatype <- utils.check.datatype(x, verbose = verbose)
     
-    # FUNCTION SPECIFIC ERROR CHECKING
-    
-    if (!is.null(loc.list) && !is.null(first)) {
+   # Function-specific error checking -----------      
+    if (!is.null(loc.list) && !is.null(first_tmp)) {
         flag <- "both"
         if (verbose >= 2) {
             cat(report(
@@ -61,7 +67,7 @@ gl.drop.loc <- function(x,
         if (verbose >= 2) {
             cat(report("  List of loci to drop has been specified\n"))
         }
-    } else if (!is.null(first)) {
+    } else if (!is.null(first_tmp)) {
         flag <- "range"
         if (verbose >= 2) {
             cat(report("  Range of loci to drop has been specified\n"))
@@ -95,13 +101,13 @@ gl.drop.loc <- function(x,
     }
     
     if (flag == "range") {
-        if (first <= 0) {
+        if (first_tmp <= 0) {
             cat(warn(
                 "  Warning: Lower limit to range of loci cannot be less than 1, set to 1\n)"
             ))
-            first <- 1
+            first_tmp <- 1
         }
-        if (first > nLoc(x)) {
+        if (first_tmp > nLoc(x)) {
             cat(
                 warn(
                     "  Warning: Upper limit to range of loci cannot be greater than the number of loci, set to",
@@ -109,19 +115,20 @@ gl.drop.loc <- function(x,
                     "\n)"
                 )
             )
-            last <- nLoc(x)
+            last_tmp <- nLoc(x)
         }
-        if (first > last) {
+        if (first_tmp > last_tmp) {
             cat(warn(
                 "  Warning: Upper limit is smaller than lower limit, reversed\n"
             ))
-            tmp <- first
-            first <- last
-            last <- tmp
+            tmp <- first_tmp
+            first_tmp <- last_tmp
+            last_tmp <- tmp
         }
     }
     
-    # DO THE JOB
+	# DO THE JOB --------------
+    # Remove individuals ------
     
     hold <- x
     
@@ -129,13 +136,11 @@ gl.drop.loc <- function(x,
         cat(report("  Deleting the specified loci\n"))
     }
     
-    # Remove duplicated loci if specified
-    
-    if (!is.null(first) && !is.null(loc.list)) {
-        list.from.range <- locNames(x)[first:last]
+    if (!is.null(first_tmp) && !is.null(loc.list)) {
+        list.from.range <- locNames(x)[first_tmp:last_tmp]
         loc.list <- unique(c(loc.list, list.from.range))
-    } else if (!is.null(first)) {
-        loc.list <- locNames(x)[first:last]
+    } else if (!is.null(first_tmp)) {
+        loc.list <- locNames(x)[first_tmp:last_tmp]
     }
     if (length(loc.list) == 0) {
         cat(warn(
@@ -145,12 +150,13 @@ gl.drop.loc <- function(x,
     } else {
         # Remove loci flagged for deletion
       
-        x2 <- x[,!x$loc.names %in% loc.list]
+        x2 <- x[,which(!x$loc.names %in% loc.list)]
         x2@other$loc.metrics <- x@other$loc.metrics[!x$loc.names %in% loc.list,]
     }
-    
-    # REPORT A SUMMARY
-    
+    # End block -----------
+	
+# REPORT A SUMMARY -------------
+    # Summary of outcomes --------------    
     if (verbose >= 3) {
         cat("  Summary of recoded dataset\n")
         cat(paste("    Original No. of loci:", nLoc(hold), "\n"))
@@ -159,15 +165,15 @@ gl.drop.loc <- function(x,
         # cat(paste(' No. of individuals:', nInd(x2),'\n')) cat(paste(' No. of populations: ', nPop(x2),'\n'))
     }
     
-    # ADD TO HISTORY
+    # ADD TO HISTORY -------------
     nh <- length(x2@other$history)
     x2@other$history[[nh + 1]] <- match.call()
     
-    # FLAG SCRIPT END
+    # FLAG SCRIPT END --------------------
     
     if (verbose >= 1) {
         cat(report("Completed:", funname, "\n"))
     }
-    
+    # End block -------------
     return(x2)
 }
