@@ -1,25 +1,35 @@
 #' @name gl.make.recode.pop
+# Preliminaries -- Parameter specifications -------------- 
 #' @title Creates a proforma recode_pop_table file for reassigning population
 #'  names
 #' @description
 #' Renaming populations may be required when there have been errors in
-#' assignment arising in the process from sample to DArT files or when one
+#' assignment arising in the process from sample to sequence files or when one
 #' wishes to amalgamate populations, or delete populations. Recoding populations
 #' can also be done with a recode table (csv).
 #' @details
-#' This script facilitates the construction of a recode table by producing a
+#' This function facilitates the construction of a recode table by producing a
 #' proforma file with current population names in two identical columns. Edit
-#' the second column to reassign populations. Use keyword Delete to delete a
+#' the second column to reassign populations. Use keyword 'Delete' to delete a
 #' population.
+#' 
+#' When caution needs to be exercised because of the potential for breaking the
+#'  'chain of evidence' associated with the samples, recoding individuals using
+#'  a recode table (csv) can provide a clear record of the changes.
+#'  
+#' Use outpath=getwd() or when calling this function to direct output files 
+#' to your working directory.
+#' 
+#' The function works with both genlight objects
+#' containing SNP genotypes and Tag P/A data (SilicoDArT).
 #'
-#' Apply the recoding using gl.recode.pop().
+#' Apply the recoding using gl.recode.pop(). 
 #'
-#' @param x Name of the genlight object containing the SNP data [required].
+#' @param x Name of the genlight object [required].
 #' @param out.recode.file File name of the output file (including extension)
 #'  [default recode_pop_table.csv].
 #' @param outpath Path where to save the output file
-#' [default tempdir(), mandated by CRAN]. Use outpath=getwd() or outpath='.'
-#' when calling this function to direct output files to your working directory.
+#' [default tempdir(), mandated by CRAN]. 
 #' @param verbose Verbosity: 0, silent or fatal errors; 1, begin and end; 2,
 #' progress log; 3, progress and results summary; 5, full report
 #' [default 2 or as specified using gl.set.verbosity].
@@ -29,11 +39,13 @@
 #'  \url{https://groups.google.com/d/forum/dartr}
 #' @examples
 #' result <- gl.make.recode.pop(testset.gl,out.recode.file='test.csv',outpath=tempdir(),verbose=2)
-
+#' 
+# Function ---------------
 gl.make.recode.pop <- function(x,
                                out.recode.file = "recode_pop_table.csv",
                                outpath = tempdir(),
                                verbose = NULL) {
+  # Preliminaries --------------------
     # SET VERBOSITY
     verbose <- gl.check.verbosity(verbose)
     
@@ -41,21 +53,21 @@ gl.make.recode.pop <- function(x,
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
                      build = "Jody",
-                     verbosity = verbose)
+                     verbose = verbose)
     
     # CHECK DATATYPE
     datatype <- utils.check.datatype(x, verbose = verbose)
     
     outfilespec <- file.path(outpath, out.recode.file)
     
-    # FUNCTION SPECIFIC ERROR CHECKING
+    # Function specific error checking ---------------------
     
     if (is.null(pop(x)) |
         is.na(length(pop(x))) | length(pop(x)) <= 0) {
         stop(error("Fatal Error: Population names not detected\n"))
     }
     
-    # DO THE JOB
+    # DO THE JOB --------------------
     
     # if (verbose >= 2) {cat(' Creating draft lookup table\n')}
     mat <- cbind(levels(pop(x)), levels(pop(x)))
@@ -74,11 +86,12 @@ gl.make.recode.pop <- function(x,
         col.names = FALSE
     )
     
-    # FLAG SCRIPT END
+    # FLAG SCRIPT END ---------------
     
     if (verbose > 0) {
         cat(report("Completed:", funname, "\n"))
     }
+    # Block end ----------------------
     
     return(NULL)
 }
