@@ -56,7 +56,7 @@ gl.read.csv <- function(filename,
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
                      build = "Jackson",
-                     verbosity = verbose)
+                     verbose = verbose)
     
     # FUNCTION SPECIFIC ERROR CHECKING
     
