@@ -71,7 +71,7 @@ gl.read.silicodart <- function(filename,
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
                      build = "Jackson",
-                     verbosity = verbose)
+                     verbose = verbose)
     
     # DO THE JOB
     
@@ -342,6 +342,8 @@ gl.read.silicodart <- function(filename,
     names(glout@other$loc.metrics.flags) <- recalc.flags
     glout@other$verbose <- 2
     
+    glout <- gl.compliance.check(glout)
+    
     # FLAG SCRIPT END
     
     if (verbose >= 1) {
