@@ -90,7 +90,7 @@ gl.report.hamming <- function(x,
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
                      build = "Jody",
-                     verbosity = verbose)
+                     verbose = verbose)
     
     # CHECK DATATYPE
     datatype <- utils.check.datatype(x, verbose = verbose)
@@ -242,7 +242,7 @@ gl.report.hamming <- function(x,
     
     # Determine the loss of loci for a given threshold using quantiles
     nl <- nLoc(x)
-    quantile_res <- quantile(d, probs = seq(0, 1, 1 / 20),type=1)
+    quantile_res <- quantile(d, probs = seq(0, 1, 1 / 20),type=1,na.rm = TRUE)
     retained <- unlist(lapply(quantile_res, function(y) {
         res <- sum(d >= y)
     }))
