@@ -102,7 +102,7 @@ gl.report.parent.offspring <- function(x,
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
                      build = "Jody",
-                     verbosity = verbose)
+                     verbose = verbose)
     
     # CHECK DATATYPE
     datatype <- utils.check.datatype(x, verbose = verbose)
@@ -229,7 +229,7 @@ gl.report.parent.offspring <- function(x,
                 ), 4)
         }
         # ordering by number of outliers
-        outliers <- outliers[order(outliers, decreasing = T),]
+        outliers <- outliers[order(outliers$Outlier, decreasing = T),]
         # removing duplicated values
         outliers <- outliers[!duplicated(outliers),]
         # removing NAs
@@ -307,6 +307,5 @@ gl.report.parent.offspring <- function(x,
     }
     
     # RETURN
-    invisible(x)
-    
+    return(df)
 }
