@@ -80,7 +80,7 @@ gl2bpp <- function(x,
   funname <- match.call()[[1]]
   utils.flag.start(func = funname,
                    build = "Jackson",
-                   verbosity = verbose)
+                   verbose = verbose)
   
   # CHECK DATATYPE
   datatype <- utils.check.datatype(x, accept = "SNP", verbose = verbose)
