@@ -36,10 +36,14 @@
 #' loc.all e.g. 'G/A') and the position of the SNP in slot position of the
 #'  ```genlight``` object (see testset.gl@position and testset.gl@loc.all for
 #'  how to format these slots.)
+#'  
+#'  When trimmed.sequence = FALSE, loci that are not SNPs are removed. 
 #'
 #' @param x Name of the genlight object containing the SNP data [required].
 #' @param method One of 1 | 2 | 3 | 4. Type method=0 for a list of options 
 #' [method=1].
+#' @param trimmed.sequence Include Trimmedsequence. If FALSE, only method 3 and 
+#' 4 are available [default = TRUE].
 #' @param outfile Name of the output file (fasta format) ["output.fasta"].
 #' @param outpath Path where to save the output file (set to tempdir by default)
 #' @param probar If TRUE, a progress bar will be displayed for long loops 
@@ -69,6 +73,7 @@
 
 gl2fasta <- function(x,
                      method = 1,
+                     trimmed.sequence = TRUE,
                      outfile = "output.fasta",
                      outpath = tempdir(),
                      probar = FALSE,
@@ -82,7 +87,7 @@ gl2fasta <- function(x,
     funname <- match.call()[[1]]
     utils.flag.start(func = funname,
                      build = "Jackson",
-                     verbosity = verbose)
+                     verbose = verbose)
     
     # CHECK DATATYPE
     datatype <- utils.check.datatype(x, accept = "SNP", verbose = verbose)
@@ -111,6 +116,14 @@ gl2fasta <- function(x,
         }
     }
     
+    if (length(x@loc.all) != nLoc(x)) {
+      stop(error(
+        "Fatal Error: Data must include type of alleles in the @loc.all slot.\n"))
+    }
+    
+    if(trimmed.sequence){
+    
+    
     if (length(x@other$loc.metrics$TrimmedSequence) != nLoc(x)) {
         stop(
             error(
@@ -118,6 +131,7 @@ gl2fasta <- function(x,
             )
         )
     }
+    
     if (length(x@position) != nLoc(x)) {
         stop(
             error(
@@ -125,10 +139,6 @@ gl2fasta <- function(x,
             )
         )
     }
-    if (length(x@loc.all) != nLoc(x)) {
-        stop(error(
-  "Fatal Error: Data must include type of alleles in the @loc.all slot.\n"))
-    }
     
     if (method == 1 && verbose >= 2) {
         cat(
@@ -334,8 +344,7 @@ gl2fasta <- function(x,
         for (i in 1:r) {
             for (j in 1:c) {
                 # Reassign some variables
-                trimmed <-
-                    as.character(x@other$loc.metrics$TrimmedSequence[j])
+                trimmed <- as.character(x@other$loc.metrics$TrimmedSequence[j])
                 snp <- x@loc.all[j]
                 snpos <- x@position[j]
                 # Shift the index for snppos to start from 1 not zero
@@ -409,6 +418,197 @@ gl2fasta <- function(x,
         # Close the output fastA file
         sink()
         
+    }
+    }
+    
+    if(!trimmed.sequence){
+      # removing loci that are not SNPs
+      no_SNP <- which(nchar(x@loc.all) >3 )
+      x <- gl.drop.loc(x,loc.list = locNames(x)[no_SNP])
+      
+      if (method == 1 ) {
+        stop(
+          error(
+            "  Method 1 is not available if Trimmedsequence = FALSE"
+          )
+        )
+      } else if (method == 3 && verbose >= 2) {
+        cat(
+          report(
+            "  Assigning ambiguity codes to heterozygote SNPs, concatenating SNPs\n"
+          )
+        )
+      } else if (method == 2) {
+        stop(
+          error(
+            "  Method 2 is not available if Trimmedsequence = FALSE"
+          )
+        )
+      } else if (method == 4 && verbose >= 2) {
+        cat(
+          report(
+            "  Randomly allocating heterozygotes (1) to homozygotic state (0 or 2), concatenating SNPs\n"
+          )
+        )
+      } else {
+        if (verbose >= 2) {
+          cat(warn("Method not properly specified\n"))
+          cat(warn(
+            "  method=3 -- ambiguity codes, concatenate SNPs only\n"
+          ))
+          cat(
+            warn(
+              "  method=4 -- random assignment to one of the two homogeneous states, concatenate SNPs only\n"
+            )
+          )
+        }
+        stop(error("Fatal Error: Parameter method out of range.\n"))
+      }
+      
+      # DO THE JOB
+      
+      # METHOD = AMBIGUITY CODES
+      
+      if (method == 3) {
+        allnames <- locNames(x)
+        snp <- as.character(x@loc.all)
+        snpmatrix <- as.matrix(x)
+        
+        # Create a lookup table for the ambiguity codes A T G C A A W R M) T W T K Y G R K G S C M Y S C
+        
+        conversion <-
+          matrix(
+            c(
+              "A",
+              "W",
+              "R",
+              "M",
+              "W",
+              "T",
+              "K",
+              "Y",
+              "R",
+              "K",
+              "G",
+              "S",
+              "M",
+              "Y",
+              "S",
+              "C"
+            ),
+            nrow = 4,
+            ncol = 4
+          )
+        colnames(conversion) <- c("A", "T", "G", "C")
+        rownames(conversion) <- colnames(conversion)
+        
+        # Extract alleles 1 and 2
+        allele1 <- gsub("(.)/(.)", "\\1", snp, perl = T)
+        allele2 <- gsub("(.)/(.)", "\\2", snp, perl = T)
+        
+        sink(outfilespec)
+        
+        for (i in 1:nInd(x)) {
+          seq <- NA
+          for (j in 1:nLoc(x)) {
+            if (is.na(snpmatrix[i, j])) {
+              code <- "N"
+            } else {
+              if (snpmatrix[i, j] == 0) {
+                a1 <- allele1[j]
+                a2 <- allele1[j]
+              }
+              if (snpmatrix[i, j] == 1) {
+                a1 <- allele1[j]
+                a2 <- allele2[j]
+              }
+              if (snpmatrix[i, j] == 2) {
+                a1 <- allele2[j]
+                a2 <- allele2[j]
+              }
+              code <- conversion[a1, a2]
+            }
+            
+            seq[j] <- code
+            
+          }
+          # Join all the trimmed sequence together into one long 'composite' haplotype
+          result <- paste(seq, sep = "", collapse = "")
+          # Write the results to file in fastA format
+          cat(paste0(">", indNames(x)[i], "_", pop(x)[i], "\n"))
+          cat(result, " \n")
+        }
+        
+        # Close the output fastA file
+        sink()
+      }
+      
+      # METHOD = RANDOM ASSIGNMENT
+      
+      if (method == 4) {
+        # Randomly allocate heterozygotes (1) to homozygote state (0 or 2)
+        matrix <- as.matrix(x)
+        r <- nrow(matrix)
+        c <- ncol(matrix)
+        for (i in 1:r) {
+          for (j in 1:c) {
+            if (matrix[i, j] == 1 && !is.na(matrix[i, j])) {
+              # Score it 0 or 2
+              matrix[i, j] <- (sample(1:2, 1) - 1) * 2
+            }
+          }
+        }
+        
+        # Prepare the output fastA file
+        sink(outfilespec)
+        
+        # For each individual, and for each locus, generate the relevant haplotype
+        seq <- rep(" ", c)
+        
+        for (i in 1:r) {
+          for (j in 1:c) {
+            # Reassign some variables
+            snp <- x@loc.all[j]
+            
+            # If the score is homozygous for the reference allele
+            seq[j] <- gsub("(.)/(.)", "\\1", snp, perl = T)
+            
+            # If the score is homozygous for the alternate allele
+            if (matrix[i, j] == 2 && !is.na(matrix[i, j])) {
+              snpbase <- gsub("(.)/(.)", "\\1", snp, perl = T)
+              # Extract the SNP transition bases (e.g. A and T)
+              state1 <- gsub("(.)/(.)", "\\1", snp, perl = T)
+              state2 <- gsub("(.)/(.)", "\\2", snp, perl = T)
+              # Change the SNP state to the alternate
+              if (snpbase == state1) {
+                snpbase <- state2
+              } else {
+                snpbase <- state1
+              }
+              
+              seq[j] <- snpbase
+              
+            }
+            
+            # If the SNP state is missing, assign Ns
+            if (is.na(matrix[i, j])) {
+              seq[j] <- "N"
+            }
+          }
+          
+          # Join all the SNPs together into one long 'composite' haplotype
+          result <- paste(seq, sep = "", collapse = "")
+          # Write the results to file in fastA format
+          cat(paste0(">", indNames(x)[i], "_", pop(x)[i], "\n"))
+          cat(result, " \n")
+          
+        }  # Select the next individual and repeat
+        
+        # Close the output fastA file
+        sink()
+        
+      }
+      
     }
     
     # FLAG SCRIPT END
