@@ -7,9 +7,9 @@
 #' estimate. This function can take the loci, the individuals or the populations 
 #' as units over which to conduct resampling.
 #' 
-#' bold{Note} that when n is very small, jackknife resampling is not recommended.
+#' \bold{Note} that when n is very small, jackknife resampling is not recommended.
 #' 
-#' Parallel computation is implemented. The argument code{n.cores} indicates the 
+#' Parallel computation is implemented. The argument \code{n.cores} indicates the 
 #' number of core to use. If "auto" [default], it will use all but one available 
 #' cores. If the number of units is small (e.g. a few populations), there is not 
 #' real advantage in using parallel computation. On the other hand, if the number 
@@ -51,7 +51,7 @@ utils.jackknife <- function(x,
   funname <- match.call()[[1]]
   utils.flag.start(func = funname,
                    build = "Jody",
-                   verbosity = verbose)
+                   verbose = verbose)
   
   # CHECK DATATYPE
   datatype <- utils.check.datatype(x, verbose = verbose)
