@@ -3,22 +3,22 @@ WC_FST_Diploids_2Alleles <- function(Sample_Mat) {
     # has three columns (homo_p,m heterozygotes, and homo_q) and
     ## a row for each population
     
-    sample_sizes = rowSums(Sample_Mat)
-    n_ave = mean(sample_sizes)
-    n_pops = nrow(Sample_Mat)  #r
-    r = n_pops
-    n_c = (n_pops * n_ave - sum(sample_sizes ^ 2) / (n_pops * n_ave)) /
+    sample_sizes <-rowSums(Sample_Mat)
+    n_ave <-mean(sample_sizes)
+    n_pops <-nrow(Sample_Mat)  #r
+    r <-n_pops
+    n_c <-(n_pops * n_ave - sum(sample_sizes ^ 2) / (n_pops * n_ave)) /
         (n_pops - 1)
-    p_freqs = (Sample_Mat[, 1] + Sample_Mat[, 2] / 2) / sample_sizes
-    p_ave = sum(sample_sizes * p_freqs) / (n_ave * n_pops)
+    p_freqs <-(Sample_Mat[, 1] + Sample_Mat[, 2] / 2) / sample_sizes
+    p_ave <-sum(sample_sizes * p_freqs) / (n_ave * n_pops)
     
-    s2 = sum(sample_sizes * (p_freqs - p_ave) ^ 2) / ((n_pops - 1) * n_ave)
+    s2 <-sum(sample_sizes * (p_freqs - p_ave) ^ 2) / ((n_pops - 1) * n_ave)
     if (s2 == 0) {
         return(0)
     }
     
-    h_freqs = Sample_Mat[, 2] / sample_sizes
-    h_ave = sum(sample_sizes * h_freqs) / (n_ave * n_pops)
+    h_freqs <-Sample_Mat[, 2] / sample_sizes
+    h_ave <-sum(sample_sizes * h_freqs) / (n_ave * n_pops)
     
     a <-
         n_ave / n_c * (s2 - 1 / (n_ave - 1) * (p_ave * (1 - p_ave) - ((r - 1) /
@@ -40,7 +40,7 @@ WC_FST_Diploids_2Alleles <- function(Sample_Mat) {
     He <- 1 - sum(p_ave ^ 2, (1 - p_ave) ^ 2)
     
     FST <- a / (a + b + c)
-    FSTNoCorr = aNoCorr / (aNoCorr + bNoCorr + cNoCorr)
+    FSTNoCorr <-aNoCorr / (aNoCorr + bNoCorr + cNoCorr)
     
     return(
         list(
@@ -104,15 +104,15 @@ utils.outflank.MakeDiploidFSTMat <- function(SNPmat,
         nloci <- length(locusname)
         FSTmat <- matrix(NA, nrow = nloci, ncol = 8)
         for (i in 1:nloci) {
-            FSTmat[i,] = unlist(getFSTs_diploids(popname, SNPmat[, i]))
+            FSTmat[i,] <-unlist(getFSTs_diploids(popname, SNPmat[, i]))
             if (i %% 10000 == 0) {
                 print(paste(i, "done of", nloci))
             }
         }
-        outTemp = as.data.frame(FSTmat)
-        outTemp = cbind(locusname, outTemp)
+        outTemp <-as.data.frame(FSTmat)
+        outTemp <-cbind(locusname, outTemp)
         
-        colnames(outTemp) = c(
+        colnames(outTemp) <-c(
             "LocusName",
             "He",
             "FST",
@@ -131,13 +131,13 @@ utils.outflank.MakeDiploidFSTMat <- function(SNPmat,
 getFSTs_diploids <- function(popNameList,
                             SNPDataColumn) {
     # eliminating the missing data for this locus
-    popnames = unlist(as.character(popNameList))
-    popNameTemp = popnames[which(SNPDataColumn != 9)]
-    snpDataTemp = SNPDataColumn[SNPDataColumn != 9]
+    popnames <-unlist(as.character(popNameList))
+    popNameTemp <-popnames[which(SNPDataColumn != 9)]
+    snpDataTemp <-SNPDataColumn[SNPDataColumn != 9]
     
     HetCounts <-
         tapply(snpDataTemp, list(popNameTemp, snpDataTemp), length)
-    HetCounts[is.na(HetCounts)] = 0
+    HetCounts[is.na(HetCounts)] <-0
     
     # Case: all individuals are genetically identical at this locus
     if (dim(HetCounts)[2] == 1) {
@@ -157,16 +157,16 @@ getFSTs_diploids <- function(popNameList,
     
     if (dim(HetCounts)[2] == 2) {
         if (paste(colnames(HetCounts), collapse = "") == "01") {
-            HetCounts = cbind(HetCounts, `2` = 0)
+            HetCounts <-cbind(HetCounts, `2` = 0)
         }
         if (paste(colnames(HetCounts), collapse = "") == "12") {
-            HetCounts = cbind(`0` = 0, HetCounts)
+            HetCounts <-cbind(`0` = 0, HetCounts)
         }
         if (paste(colnames(HetCounts), collapse = "") == "02") {
-            HetCounts = cbind(HetCounts[, 1], `1` = 0, HetCounts[, 2])
+            HetCounts <-cbind(HetCounts[, 1], `1` = 0, HetCounts[, 2])
         }
     }
     
-    out = WC_FST_Diploids_2Alleles(HetCounts)
+    out <-WC_FST_Diploids_2Alleles(HetCounts)
     return(out)
 }
